==> jc-1.4.0.tar.gz: soot/jimple/spark/fieldrw/FieldWriteTag.h <==
// public class soot.jimple.spark.fieldrw.FieldWriteTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 26c009a8a59d47e0 soot_jimple_spark_fieldrw_FieldRWTag
// @dep_class dcf5ad5c1c03736c soot_jimple_spark_fieldrw_FieldWriteTag

// header file dependencies
// @dep_header soot_jimple_spark_fieldrw_FieldRWTag

#include "soot/jimple/spark/fieldrw/FieldRWTag.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldWriteTag_H_
#define _JC_soot_jimple_spark_fieldrw_FieldWriteTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$refs	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vmethods	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtable	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldWriteTag$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldWriteTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldWriteTag$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object *);
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods	soot_jimple_spark_fieldrw_FieldRWTag;
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vmethods	soot_jimple_spark_fieldrw_FieldWriteTag;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$refs {
    _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_refs	soot_jimple_spark_fieldrw_FieldWriteTag;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldWriteTag;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object {
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype _jc_soot_jimple_spark_fieldrw_FieldWriteTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldWriteTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldWriteTag$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldWriteTag_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/fieldrw/FieldWriteTag.h <==
// public class soot.jimple.spark.fieldrw.FieldWriteTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 26c009a8a59d47e0 soot_jimple_spark_fieldrw_FieldRWTag
// @dep_class dcf5ad5c1c03736c soot_jimple_spark_fieldrw_FieldWriteTag

// header file dependencies
// @dep_header soot_jimple_spark_fieldrw_FieldRWTag

#include "soot/jimple/spark/fieldrw/FieldRWTag.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldWriteTag_H_
#define _JC_soot_jimple_spark_fieldrw_FieldWriteTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$refs	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vmethods	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtable	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldWriteTag$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_fieldrw_FieldWriteTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldWriteTag$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_fieldrw_FieldRWTag$vmethods	soot_jimple_spark_fieldrw_FieldRWTag;
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vmethods	soot_jimple_spark_fieldrw_FieldWriteTag;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$refs {
    _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_refs	soot_jimple_spark_fieldrw_FieldWriteTag;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_refs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_fieldrw_FieldRWTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldRWTag;
    _jc_soot_jimple_spark_fieldrw_FieldWriteTag$sub_nonrefs	soot_jimple_spark_fieldrw_FieldWriteTag;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldWriteTag$object {
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldWriteTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldWriteTag$vtype _jc_soot_jimple_spark_fieldrw_FieldWriteTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldWriteTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldWriteTag$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldWriteTag_H_ */
